@@ -1,13 +1,13 @@
-/* @(#)cmds.c	1.41 01/10/28 Copyright 1984 J. Schilling */
+/* @(#)cmds.c	1.42 04/03/13 Copyright 1984-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)cmds.c	1.41 01/10/28 Copyright 1984 J. Schilling";
+	"@(#)cmds.c	1.42 04/03/13 Copyright 1984-2004 J. Schilling";
 #endif
 /*
  *	Commands that deal with various things that do not apply to other
  *	systematic categories.
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #include "ved.h"
@@ -67,7 +67,7 @@ vnorm(wp)
 		epos_t	diff = (epos_t)0;
 
 	if (wp->overstrikemode) {
-		if ((dels = min(n, wp->eof-wp->dot)) > 0){
+		if ((dels = min(n, wp->eof-wp->dot)) > 0) {
 			dispup(wp, wp->dot, wp->dot+dels);
 			delete(wp, dels);
 			setpos(wp);
@@ -85,7 +85,7 @@ vnorm(wp)
 
 	if (wp->lastch != '\n' &&
 	    ((wp->wrapmargin && cursor.hp > (wp->llen - wp->wrapmargin)) ||
-	     (wp->maxlinelen && cursor.hp > wp->maxlinelen))) {
+	    (wp->maxlinelen && cursor.hp > wp->maxlinelen))) {
 		save = wp->dot;
 		if ((wp->dot = revword(wp, save, (ecnt_t)1)) > revline(wp, save, (ecnt_t)1)) {
 			update(wp);
@@ -149,11 +149,11 @@ vnl(wp)
 		indent = c.hp;
 		wp->lastch = '\n';
 		vnorm(wp);
-	  	update(wp);
+		update(wp);
 		wp->lastch = '\t';
 		wp->curnum = indent / wp->tabstop;
 		vnorm(wp);
-	  	update(wp);
+		update(wp);
 		wp->lastch = ' ';
 		wp->curnum = indent % wp->tabstop;
 		vnorm(wp);
@@ -216,7 +216,7 @@ vmode(wp)
 	writemsg(wp, "Mode?(DORV8)"); MOVE_CURSOR(wp, 0, 12); flush();
 	ch = nigchar(wp);
 
-	switch(ch) {
+	switch (ch) {
 
 	case 'v':
 	case 'V':
@@ -256,8 +256,8 @@ vmode(wp)
 		modeprint(wp, "DOS", wp->dosmode);
 		modeprint(wp, "Raw8", wp->raw8);
 		modeprint(wp, "Overstrike", wp->overstrikemode);
-		wait_for_confirm(wp); 
-		vredisp(wp); 
+		wait_for_confirm(wp);
+		vredisp(wp);
 		break;
 	default:
 		abortmsg(wp);
@@ -334,7 +334,7 @@ vsewhere(wp)
  */
 LOCAL epos_t
 where(wp, loc)
-		 ewin_t	*wp;
+		ewin_t	*wp;
 	register epos_t loc;
 {
 	register epos_t newdot = (epos_t)0;
@@ -347,7 +347,7 @@ where(wp, loc)
 			break;
 		}
 	}
-	return(line);
+	return (line);
 }
 
 /*
@@ -422,7 +422,7 @@ tocntrl(c)
 	if (c >= (unsigned)'@' && c <= (unsigned)('@' + 0x1F))
 		c &= 0x1F;
 
-	return c;
+	return (c);
 }
 
 /*
@@ -437,7 +437,7 @@ vhex(wp)
 
 	hbuf[0] = '0';
 	hbuf[1] = 'x';
-	if (getcmdline(wp, UC &hbuf[2], sizeof(hbuf) - 2, "Quote: 0x")) {
+	if (getcmdline(wp, UC &hbuf[2], sizeof (hbuf) - 2, "Quote: 0x")) {
 		if (*astoi(hbuf, &i) != '\0')
 			writeerr(wp, "BAD ARG");
 		else {
