@@ -1,12 +1,12 @@
-/* @(#)cursorcmds.c	1.29 01/03/05 Copyright 1984 J. Schilling */
+/* @(#)cursorcmds.c	1.30 04/03/13 Copyright 1984-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)cursorcmds.c	1.29 01/03/05 Copyright 1984 J. Schilling";
+	"@(#)cursorcmds.c	1.30 04/03/13 Copyright 1984-2004 J. Schilling";
 #endif
 /*
  *	Commands that deal with cursor movement
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -19,9 +19,9 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #include "ved.h"
@@ -337,10 +337,11 @@ vpageup(wp)
 	} else {
 /*cdbg("up: %d", wp->curnum * (wp->psize + 1) - wp->optline);*/
 		wp->dot = revline(wp, wp->window, wp->curnum * (wp->psize + 1) - wp->optline);
-/*	???
+#ifdef	__comment__
+/* XXX	??? */
 		wp->dot = revline(wp, wp->dot, wp->curnum * (wp->psize + 1));
 		wp->window = revline(wp, wp->window, wp->curnum * (wp->psize + 1));
-*/
+#endif
 	}
 }
 
@@ -367,10 +368,11 @@ vpagedwn(wp)
 	} else {
 /*cdbg("down: %d", wp->curnum * (wp->psize - 2) + wp->optline);*/
 		wp->dot = forwline(wp, wp->window, wp->curnum * (wp->psize - 2) + wp->optline);
-/*	???
+#ifdef	__comment__
+/* XXX	??? */
 		wp->dot = forwline(wp, wp->dot, wp->curnum * (wp->psize - 1));
 		wp->window = forwline(wp, wp->window, wp->curnum * (wp->psize - 1));
-*/
+#endif
 	}
 }
 
@@ -629,16 +631,16 @@ srchbrack(wp, begin, ch, sfunc)
 	while (n > 0) {
 		begin = (*sfunc)(wp, begin, spat, plen, 0);
 		if (begin > wp->eof)
-			return(begin);
+			return (begin);
 		if (extract(wp, begin-1, b, 1) != 1)
-			return(wp->eof+2);
+			return (wp->eof+2);
 /*		writeerr("C: '%c' p %d", b[0], begin);sleep(1);*/
 		if (b[0] == ch)
 			n++;
 		else
 			n--;
 	}
-	return(--begin);
+	return (--begin);
 }
 
 /*
@@ -660,7 +662,7 @@ searchbrack(wp, begin, ch)
 		begin = srchbrack(wp, begin, ch, search);
 	}
 	wp->magic = omagic;
-	return(begin);
+	return (begin);
 }
 
 /*
