@@ -1,12 +1,12 @@
-/* @(#)execcmds.c	1.37 01/10/27 Copyright 1984 J. Schilling */
+/* @(#)execcmds.c	1.40 04/03/13 Copyright 1984-1986, 1995-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)execcmds.c	1.37 01/10/27 Copyright 1984 J. Schilling";
+	"@(#)execcmds.c	1.40 04/03/13 Copyright 1984-1986, 1995-2004 J. Schilling";
 #endif
 /*
  *	Commands that deal with execution of shell commands from ved
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984-1986, 1995-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -19,9 +19,9 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #include "ved.h"
@@ -40,7 +40,7 @@ EXPORT	void	vsexec		__PR((ewin_t *wp));
 LOCAL	void	execcmd		__PR((ewin_t *wp, Uchar(*)(ewin_t *wp)));
 LOCAL	void	doexec		__PR((ewin_t *wp, FILE *f));
 LOCAL	void	execute		__PR((ewin_t *wp));
-EXPORT	int	spawncmd	__PR((ewin_t *wp, char* name, char* arg));
+EXPORT	int	spawncmd	__PR((ewin_t *wp, char *name, char *arg));
 EXPORT	BOOL	white		__PR((int ch));
 LOCAL	Uchar	exbufgetc	__PR((ewin_t *wp));
 LOCAL	Uchar	extakegetc	__PR((ewin_t *wp));
@@ -53,7 +53,7 @@ vexec(wp)
 	ewin_t	*wp;
 {
 	Uchar	cmdline[XBUFSIZE];
-	
+
 	if (! (exblen = getcmdline(wp, cmdline, sizeof (cmdline), "Execute: ")))
 		return;
 	exbptr = exbase = cmdline;
@@ -126,7 +126,7 @@ execcmd(wp, nextc)
 		 * Check if this is a quoted take-buffer name.
 		 */
 		if ((c = (*nextc)(wp)) != '\\') {
-			for (i = 0; !white(c) && i < (NAMESIZE-1);) {
+			for (i = 0; !white(c) && i < (NAMESIZE-1); ) {
 				tbuf[i++] = c;
 				c = (*nextc)(wp);
 			}
@@ -174,7 +174,7 @@ doexec(wp, f)
 	if (wp->modflg)
 		writeerr(wp, "FILE MODIFIED!");
 
-	switch(c = getcmdchar(wp, NULL, "EXECUTING. PUT EDITS?(Y/W/N/F/!) ")) {
+	switch (c = getcmdchar(wp, NULL, "EXECUTING. PUT EDITS?(Y/W/N/F/!) ")) {
 
 	default:
 		abortmsg(wp);
@@ -253,7 +253,7 @@ spawncmd(wp, name, arg)
 	if (newpid == 0) {
 		signal(SIGINT, SIG_DFL);
 		signal(SIGQUIT, SIG_DFL);
-		fexecl(name, stdin, stdout, stderr, name, arg, NULL);
+		fexecl(name, stdin, stdout, stderr, name, arg, (char *)NULL);
 		comerr("Can not execute %s.\n", name);
 	}
 #ifdef	JOS
@@ -332,4 +332,3 @@ extern	char	TAKEBUF[];
 		return ('\0');
 	return (*exbptr++);
 }
-
