@@ -1,12 +1,12 @@
-/* @(#)filecmds.c	1.47 01/10/27 Copyright 1984 J. Schilling */
+/* @(#)filecmds.c	1.50 04/03/13 Copyright 1984-1986, 1989-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)filecmds.c	1.47 01/10/27 Copyright 1984 J. Schilling";
+	"@(#)filecmds.c	1.50 04/03/13 Copyright 1984-1986, 1989-2004 J. Schilling";
 #endif
 /*
  *	Commands that deal with filenames and read/write of files
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984-1986, 1989-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -19,9 +19,9 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #include "ved.h"
@@ -98,14 +98,14 @@ shellspecial(pattern, length)
 	register Uchar *pattern;
 	register int length;
 {
-	while(length-- > 0) {
-		switch(*pattern++) {
+	while (length-- > 0) {
+		switch (*pattern++) {
 
 		case '~':
-			return(TRUE);
+			return (TRUE);
 		}
 	}
-	return(FALSE);
+	return (FALSE);
 }
 
 /*
@@ -126,7 +126,7 @@ glob(wp, buf)
 	if ((sh = getenv("SHELL")) == NULL)
 		sh = "/bin/sh";
 
-	strcatl(cmd, "echo ", buf, NULL);
+	strcatl(cmd, "echo ", buf, (char *)NULL);
 /*	cdbg("cmd: %s\n", cmd);*/
 	if (fpipe(pp) == 0) {
 		write_errno(wp, "Glob pipe failed");
@@ -145,13 +145,13 @@ glob(wp, buf)
 		/* We don't want to see errors */
 		null = fileopen("/dev/null", "rwb");
 
-		fexecl(sh, null, pp[1], null, "sh", "-c", cmd, NULL);
+		fexecl(sh, null, pp[1], null, "sh", "-c", cmd, (char *)NULL);
 		write_errno(wp, "Glob exec failed");
 		_exit(-1);
 	}
 	fclose(pp[1]);
 	tmp[0] = '\0';
-	fgetline(pp[0], tmp, sizeof(tmp));
+	fgetline(pp[0], tmp, sizeof (tmp));
 	fclose(pp[0]);
 	wait(0);
 /*	cdbg("line: '%s'\n", tmp);*/
@@ -206,7 +206,7 @@ change_file(wp, file)
 		writeerr(wp, "FILE MODIFIED!");
 	if (wp->modflg || mflag) {
 
-		switch(c = getcmdchar(wp, NULL,
+		switch (c = getcmdchar(wp, NULL,
 			"CHANGING TO: %s. PUT EDITS?(Y/W/N/F/!) ", file)) {
 
 		default:
@@ -234,7 +234,7 @@ change_file(wp, file)
 	flush();
 
 	fchange(wp, file);
-	return TRUE;
+	return (TRUE);
 }
 
 /*
@@ -261,8 +261,8 @@ fchange(wp, file)
 	wp->dot = 0;
 
 	namemsg(file);
-	strncpy(C curfname, C file, sizeof(curfname));
-	curfname[sizeof(curfname)-1] = '\0';
+	strncpy(C curfname, C file, sizeof (curfname));
+	curfname[sizeof (curfname)-1] = '\0';
 	wp->curfile = curfname;
 
 	put_vedtmp(wp, TRUE);	/* save new filename */
@@ -276,7 +276,7 @@ fchange(wp, file)
 	CLEAR_SCREEN(wp);
 	defaultinfo(wp, UC NULL);
 	refreshmsg(wp);
-	(void)wrtcheck(wp, FALSE);
+	(void) wrtcheck(wp, FALSE);
 	writelockmsg(wp);
 }
 
