@@ -1,12 +1,12 @@
-/* @(#)filesubs.c	1.55 01/10/29 Copyright 1984 J. Schilling */
+/* @(#)filesubs.c	1.59 04/03/13 Copyright 1984-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)filesubs.c	1.55 01/10/29 Copyright 1984 J. Schilling";
+	"@(#)filesubs.c	1.59 04/03/13 Copyright 1984-2004 J. Schilling";
 #endif
 /*
  *	Commands that deal with non i/o file subroutines
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -19,9 +19,9 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #include "ved.h"
@@ -53,7 +53,7 @@ EXPORT	BOOL	modcheck	__PR((ewin_t *wp));
 #else
 #	define	NO_LOCK	EINVAL
 #endif
-#define	no_lock()	(errno = NO_LOCK)
+#define	no_lock()	(seterrno(NO_LOCK))
 
 /*
  * Lock the current default file.
@@ -77,7 +77,7 @@ lockfile(wp, filename)
 	switch (ret) {
 
 	case LOCK_LOCAL:
-		wp->eflags |= FLOCKLOCAL;		
+		wp->eflags |= FLOCKLOCAL;
 	case LOCK_OK:
 		wp->curfd = f;
 		break;
@@ -123,9 +123,9 @@ check_lock()
 	 * locked. We need to add EWOULDBLOCK as *BSD returns this undocumented
 	 * value.
 	 */
-	return (errno == EACCES || errno == EAGAIN
+	return (geterrno() == EACCES || geterrno() == EAGAIN
 #ifdef EWOULDBLOCK
-						|| errno == EWOULDBLOCK
+						|| geterrno() == EWOULDBLOCK
 #endif
 	?  LOCK_ALREADY : LOCK_CANNOT);
 }
@@ -140,6 +140,9 @@ lockfd(f)
 	int	ret	= LOCK_CANNOT;
 	BOOL	didlock	= FALSE;
 
+	if (nolock)
+		return (LOCK_OK);
+
 #ifdef	HAVE_LOCKF
 #undef	FOUND_LOCK
 #define	FOUND_LOCK
@@ -149,7 +152,7 @@ lockfd(f)
 	 * It also supports locking for all machines that
 	 * use the file via NFS.
 	 */
-	errno = 0;
+	seterrno(0);
 	if (lockf(f, F_TLOCK, 0) < 0) {
 		ret = check_lock();
 	} else {
@@ -167,7 +170,7 @@ lockfd(f)
 	 * use the file via NFS.
 	 */
 	if (ret == LOCK_CANNOT) {
-		errno = 0;
+		seterrno(0);
 		if (lock_fcntl(f) < 0) {
 			ret = check_lock();
 		} else {
@@ -196,7 +199,7 @@ lockfd(f)
 	 * looks like a method from the past.
 	 */
 	if (ret != LOCK_ALREADY) {
-		errno = 0;
+		seterrno(0);
 		if (flock(f, LOCK_EX | LOCK_NB) < 0) {
 			if (!didlock)
 				ret = check_lock();
@@ -224,12 +227,12 @@ lock_fcntl(f)
 	int	ret;
 
 	fl.l_whence = 0;
-        fl.l_start = 0;
-        fl.l_len = 0;
-        fl.l_type = 0;
+	fl.l_start = 0;
+	fl.l_len = 0;
+	fl.l_type = 0;
 
 	fl.l_type |= F_WRLCK;
-	
+
 	ret = fcntl(f, F_SETLK, &fl);
 	return (ret);
 #else
@@ -260,14 +263,15 @@ getfmodes(name)
 	FILEDESC	fd;
 
 	if (status(C name, &fd) < 0)
-		return -1;
-	return fd.f_modes;
+		return (-1);
+	return (fd.f_modes);
 }
 
 /*
  * Set the file permissions in UNIX flavor
  */
-int chmod(name, modes)
+int
+chmod(name, modes)
 	char	*name;
 	int	modes;
 {
@@ -293,8 +297,13 @@ getfmodes(name)
 	struct stat	fd;
 
 	if (stat(C name, &fd) < 0)
-		return -1;
-	return fd.st_mode;
+		return (-1);
+
+	/*
+	 * We are only interested in the file permissions which will fit into
+	 * an 'int' as long as it hold >= 12 bits.
+	 */
+	return ((int)fd.st_mode);
 }
 
 #endif
@@ -327,7 +336,7 @@ readable(name)
 {
 	int	ret;
 
-	ret = access((char *)name, R_OK);/* XXX nur OK wenn uid == euid !!! */
+	ret = access((char *)name, R_OK); /* XXX nur OK wenn uid == euid !!! */
 
 	if (ret < 0)
 		return (FALSE);
@@ -343,7 +352,7 @@ writable(name)
 {
 	int	ret;
 
-	ret = access((char *)name, W_OK);/* XXX nur OK wenn uid == euid !!! */
+	ret = access((char *)name, W_OK); /* XXX nur OK wenn uid == euid !!! */
 
 	if (ret < 0)
 		return (geterrno() == ENOENT);
