@@ -1,12 +1,12 @@
-/* @(#)macro.c	1.32 01/03/04 Copyright 1984 J. Schilling */
+/* @(#)macro.c	1.36 04/03/13 Copyright 1984-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)macro.c	1.32 01/03/04 Copyright 1984 J. Schilling";
+	"@(#)macro.c	1.36 04/03/13 Copyright 1984-2004 J. Schilling";
 #endif
 /*
  *	The macro package for VED
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -19,9 +19,9 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*
@@ -49,7 +49,6 @@ static	char sccsid[] =
 
 #include "ved.h"
 #include <strdefs.h>
-#include <vadefs.h>
 #ifdef	JOS
 #	include <error.h>
 #else
@@ -57,8 +56,8 @@ static	char sccsid[] =
 #	include <pwd.h>
 #endif
 
-#define	M_NAMELEN	16
-#define	M_STRINGLEN	128
+#define	M_NAMELEN	256
+#define	M_STRINGLEN	8192
 #define	M_DEPTH		10
 
 extern	int	mflag;
@@ -82,23 +81,21 @@ typedef struct m_node mac_t;
 
 struct m_node {
 	mac_t	*m_next;
-	char	m_name[M_NAMELEN + 1];
-	char	m_string[M_STRINGLEN + 1];
+	char	*m_name;
+	char	*m_string;
 };
 
 LOCAL	mac_t	*first_macro;
 
-EXPORT	char*	myhome		__PR((void));
+EXPORT	char *	myhome		__PR((void));
 EXPORT	void	macro_init	__PR((ewin_t *wp));
 EXPORT	void	vxmac		__PR((ewin_t *wp));
 EXPORT	void	vmac		__PR((ewin_t *wp));
 EXPORT	int	gmacro		__PR((void));
 EXPORT	void	vemac		__PR((ewin_t *wp));
 EXPORT	void	macro_reinit	__PR((ewin_t *wp));
-LOCAL	void	add_node	__PR((char* mn, char* ms));
-LOCAL	char*	get_macro	__PR((ewin_t *wp, int c));
-/* PRINTFIKE2 */ 
-LOCAL	void	macro_error	__PR((ewin_t *wp, char* s, ...)) __printflike__(2, 3);
+LOCAL	void	add_node	__PR((char *mn, char *ms));
+LOCAL	char *	get_macro	__PR((ewin_t *wp, int c));
 
 /*
  * Try to get the user's home directory.
@@ -139,17 +136,18 @@ macro_init(wp)
 	ewin_t	*wp;
 {
 	register FILE	*f;
-	register int	state;
+	register int	state;	/* 0 == name, 1 == string, 2 == comment */
 	register int	n;
 	register char	*s;
 	register char	lc;
 	register int	c;
-		 char	fname[129];
-		 char	m_name[M_NAMELEN + 1], m_string[M_STRINGLEN + 1];
+		char	fname[1024];
+		char	m_name[M_NAMELEN + 1];
+		char	m_string[M_STRINGLEN + 1];
 
 	first_macro = 0;
 
-	strcatl(fname, myhome(), "/.vedmac", NULL);
+	snprintf(fname, sizeof (fname), "%s%s", myhome(), "/.vedmac");
 	if ((f = fileopen(fname, "rb")) == (FILE *) NULL) {
 		if (geterrno() == ENOENT)
 			return;
@@ -162,23 +160,44 @@ macro_init(wp)
 	s = m_name;
 	for (;;) {
 		c = getc(f);
-		if (n-- < 0) {
-			macro_error(wp, "%.8s: Bad macro form. ", m_name);
+		if (c == EOF)
 			break;
-		}
-		if (c < 0)
-			break;
-		if (state == 0 && c == '\n')
-			continue;
 
-		if (state == 2) {
+		if (state == 0 && c == '\n') {	/* empty line / ln without : */
+			if (s != m_name) {
+				*s = '\0';
+				writeerr(wp, "%.8s Bad macro name.", m_name);
+				sleep(1);
+				lc = 0;
+				n = M_NAMELEN;
+				s = m_name;
+			}
+			continue;
+		}
+
+		if (n-- < 0) {
+			*s = '\0';
+			writeerr(wp, "%.8s: Bad macro form.", m_name);
+			sleep(1);
+			/*
+			 * Eat rest of line.
+			 */
+			while ((c = getc(f)) != EOF) {
+				if (c == '\n')
+					break;
+			}
+			lc = 0; s = m_name; n = M_NAMELEN; state = 0;
+			continue;
+		}
+
+		if (state == 2) {		/* comment */
 			if (c == '\n') {
 				lc = 0; s = m_name; n = M_NAMELEN; state = 0;
 			}
 			continue;
 		}
 		if (c == ':') {
-			if(lc != '\\') {
+			if (lc != '\\') {
 				*s = 0;
 				if (state == 0)
 					s = m_string;
@@ -261,9 +280,9 @@ gmacro()
 			macstr = mac_start;
 			c = *macstr++;
 		} else if (mac_level > 0) {
-			macstr    = macs[--mac_level].m_str;
+			macstr	  = macs[--mac_level].m_str;
 			mac_start = macs[mac_level].m_start;
-			mflag     = macs[mac_level].m_mult;
+			mflag	  = macs[mac_level].m_mult;
 			if (mac_level)
 				return (gmacro());
 		}
@@ -287,7 +306,8 @@ vemac(wp)
 	 * XXX What will happen if we have EBCDIC ?
 	 * XXX \015 was ^M before we port to Mac OS X Darwin
 	 */
-	strcatl(command, "ved -e ", home, "/.vedmac\015n", 0);
+	snprintf(command, sizeof (command), "ved -e %s%s",
+							home, "/.vedmac\015n");
 	macstr = command;
 	mac_init = 1;
 }
@@ -318,15 +338,28 @@ add_node(mn, ms)
 	register mac_t	*tn;
 	register mac_t	*last;
 	register int	cmp;
+	register int	ln;
+	register int	ls;
 
 	/*
 	 * First create and init new macro node.
 	 */
-	tn = (mac_t *) malloc(sizeof *tn);
+	tn = (mac_t *) malloc(sizeof (*tn));
 	if (tn == (mac_t *)NULL)
 		return;
-	movebytes(mn, tn->m_name, M_NAMELEN);
-	movebytes(ms, tn->m_string, M_STRINGLEN);
+	ln = strlen(mn);
+	ls = strlen(ms);
+	if ((tn->m_name = malloc(ln+1)) == NULL) {
+		free(tn);
+		return;
+	}
+	if ((tn->m_string = malloc(ls+1)) == NULL) {
+		free(tn->m_name);
+		free(tn);
+		return;
+	}
+	*movebytes(mn, tn->m_name, ln) = '\0';
+	*movebytes(ms, tn->m_string, ls) = '\0';
 	tn->m_next = NULL;
 
 	if (first_macro == NULL) {
@@ -338,7 +371,7 @@ add_node(mn, ms)
 	 * Insert new macro in order.
 	 */
 	np = last = first_macro;
-	for (;; np = np->m_next) {
+	for (; ; np = np->m_next) {
 
 		if (np == NULL) {
 			/*
@@ -354,6 +387,8 @@ add_node(mn, ms)
 			/*
 			 * Macro is already defined
 			 */
+			free(tn->m_name);
+			free(tn->m_string);
 			free(tn);
 			return;
 		}
@@ -387,7 +422,7 @@ get_macro(wp, c)
 	ewin_t	*wp;
 	Uchar	c;
 {
-		 char	m_name[M_NAMELEN + 1];
+		char	m_name[M_NAMELEN + 1];
 	register mac_t	*tn;
 	register int	i;
 	register char	*cp;
@@ -411,30 +446,3 @@ get_macro(wp, c)
 	}
 	return (NULL);
 }
-
-/*
- * Print an error message and disable the current macro.
- */
-/* PRINTFLIKE2 */
-#ifdef	PROTOTYPES
-LOCAL void
-macro_error(ewin_t *wp, char *s, ...)
-#else
-LOCAL void
-macro_error(wp, s, va_alist)
-	ewin_t	*wp;
-	char	*s;
-	va_dcl
-#endif
-{
-	va_list	args;
-
-#ifdef	PROTOTYPES
-	va_start(args, s);
-#else
-	va_start(args);
-#endif
-	writeerr(wp, "%r", s, args);
-	va_end(args);
-	mflag = 0; first_macro = 0;
-}
