@@ -1,12 +1,12 @@
-/* @(#)map.c	1.22 01/04/29 Copyright 1986 J. Schilling */
+/* @(#)map.c	1.25 03/10/29 Copyright 1986-2003 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)map.c	1.22 01/04/29 Copyright 1986 J. Schilling";
+	"@(#)map.c	1.25 03/10/29 Copyright 1986-2003 J. Schilling";
 #endif
 /*
- *	The map package for BSH & VED 
+ *	The map package for BSH & VED
  *
- *	Copyright (c) 1986 J. Schilling
+ *	Copyright (c) 1986-2003 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -19,9 +19,9 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*
@@ -101,7 +101,7 @@ typedef struct {
 		Uchar	*st_bp;
 		Uchar	st_buf[M_NAMELEN + 1];
 } maps_t;
-	
+
 typedef struct m_map {
 	struct	m_map	*m_next;
 	char		m_from[M_NAMELEN + 1];
@@ -124,7 +124,7 @@ EXPORT	int	mapgetc		__PR((void));
 #else
 EXPORT	int	mapgetc		__PR((ewin_t *wp));
 #endif
-LOCAL	void	pushmap		__PR((char* sp, int n));
+LOCAL	void	pushmap		__PR((char *sp, int n));
 EXPORT	void	map_init	__PR((void));
 #ifdef	BSH
 EXPORT	int	rxmap		__PR((int c));
@@ -133,21 +133,21 @@ EXPORT	int	rxmap		__PR((ewin_t *wp, int c));
 #endif
 EXPORT	int	gmap		__PR((void));
 EXPORT	void	remap		__PR((void));
-EXPORT	BOOL	add_map		__PR((char* from, char* to, char *comment));
-EXPORT	BOOL	del_map		__PR((char* from));
-LOCAL	BOOL	_add_map	__PR((Uchar* mn, Uchar* ms, char *comment));
-LOCAL	BOOL	_del_map	__PR((char* mn));
+EXPORT	BOOL	add_map		__PR((char *from, char *to, char *comment));
+EXPORT	BOOL	del_map		__PR((char *from));
+LOCAL	BOOL	_add_map	__PR((Uchar *mn, Uchar *ms, char *comment));
+LOCAL	BOOL	_del_map	__PR((char *mn));
 #ifdef	BSH
 EXPORT	void	list_map	__PR((FILE * f));
-LOCAL	char*	get_map		__PR((int c));
+LOCAL	char	*get_map	__PR((int c));
 #else
 EXPORT	void	list_map	__PR((ewin_t *wp));
-LOCAL	char*	get_map		__PR((ewin_t *wp, int c));
+LOCAL	char	*get_map	__PR((ewin_t *wp, int c));
 #endif
 LOCAL	void	init_cursor_maps __PR((void));
 #ifndef	BSH
 EXPORT	void	init_fk_maps	__PR((void));
-LOCAL	char*	pretty_string	__PR((Uchar* s));
+LOCAL	char	*pretty_string	__PR((Uchar* s));
 #endif
 
 /*
@@ -178,7 +178,7 @@ mapgetc(wp)
 {
 	if (map_str.st_cnt > 0) {
 		map_str.st_cnt--;
-	 	return (*map_str.st_bp++);
+		return (*map_str.st_bp++);
 	} else {
 #ifdef	BSH
 		return (getnextc());
@@ -231,26 +231,27 @@ EXPORT void
 map_init()
 {
 	register FILE	*f;
-		 char	mapfname[512];
-		 char	linebuf[1024];
-		 char	*array[3];
-		 char	*home;
+		char	mapfname[512];
+		char	linebuf[1024];
+		char	*array[3];
+		char	*home;
 	register char	**ap;
 	register char	*lp;
 
 	home = myhome();
 	if (home != NULL) {
-		strcatl(mapfname, myhome(), slash, mapname, NULL);
+		snprintf(mapfname, sizeof (mapfname), "%s%s%s",
+						myhome(), slash, mapname);
 	} else {
 		strcpy(mapfname, mapname);
 	}
-	
+
 
 #ifdef	BSH
 	/*
 	 * Der ved kann z.Zt. noch kein map/remap nach der
 	 * Initialisierung.
-	 * 
+	 *
 	 */
 	while (first_map)
 		_del_map(first_map->m_from);
@@ -259,11 +260,11 @@ map_init()
 	init_mapstream();
 	init_cursor_maps();
 /*	init_fk_maps();*/
-	if ((f=fileopen(mapfname, for_read)) == (FILE *) NULL) {
+	if ((f = fileopen(mapfname, for_read)) == (FILE *) NULL) {
 		if (geterrno() == ENOENT)
 			return;
 #ifdef	BSH
-		error(ecantopen, mapfname, errstr(geterrno()));
+		berror(ecantopen, mapfname, errstr(geterrno()));
 #else
 		errmsg("Cannot open '%s'.\n", mapfname);
 #endif
@@ -272,13 +273,14 @@ map_init()
 
 	ap = array;
 	lp = linebuf;
-	while (fgetline(f, lp, sizeof(linebuf)) != EOF) {
+	while (fgetline(f, lp, sizeof (linebuf)) != EOF) {
 		if (breakline(lp, ':', ap, 3) < 2)
 			continue;
 		if (!add_map(ap[0], ap[1], ap[2])) {
 			/*EMPTY*/
 			/*
-error("'%s' already defined.", pretty_string(ap[0])) */ ;
+error("'%s' already defined.", pretty_string(ap[0])) */
+			;
 		}
 	}
 	fclose(f);
@@ -298,7 +300,7 @@ rxmap(wp, c)
 {
 	if (mapflag) {
 #ifdef	BSH
-		error("\nMAP ABORTED");		/* only one map at a time */
+		berror("\nMAP ABORTED");	/* only one map at a time */
 #else
 		writeerr(wp, "MAP ABORTED");	/* only one map at a time */
 		/*
@@ -399,7 +401,7 @@ _add_map(mn, ms, comment)
 	/*
 	 * First create and init new map node.
 	 */
-	tn = (smap_t *) malloc(sizeof (*tn)); 
+	tn = (smap_t *) malloc(sizeof (*tn));
 	if (tn == (smap_t *)NULL)
 		return (FALSE);
 	*movebytes((char *) mn, (char *) tn->m_from, M_NAMELEN) = '\0';
@@ -417,7 +419,7 @@ _add_map(mn, ms, comment)
 		free((char *) tn);
 		maptab[*mn]--;
 		return (FALSE);
-	}		
+	}
 
 	if (first_map == (smap_t *) NULL) {
 		first_map = tn;
@@ -428,7 +430,7 @@ _add_map(mn, ms, comment)
 	 * Insert new map in order.
 	 */
 	np = last = first_map;
-	for (;;np = np->m_next) {
+	for (; ; np = np->m_next) {
 		if (np == (smap_t *) NULL) {
 			/*
 			 * Append to end of list
@@ -484,11 +486,14 @@ _del_map(mn)
 		free((char *) np);
 		return (TRUE);
 	}
-	for (;;np = np->m_next) {
+	for (; ; np = np->m_next) {
 		if (np->m_next == (smap_t *) NULL) {
-			error("'%s' not found", mn);
 #ifdef	BSH
+			berror("'%s' not found", mn);
 			ex_status = 1;
+#else
+/*			writeerr(wp, "'%s' not found", mn);*/
+			error("'%s' not found", mn);
 #endif
 			return (FALSE);
 		}
@@ -519,7 +524,7 @@ list_map(wp)
 {
 	register	smap_t	*np;
 
-	for (np = first_map;np;np = np->m_next) {
+	for (np = first_map; np; np = np->m_next) {
 #ifdef	BSH
 		if (f == stdout) {
 			printf("%-16s ", pretty_string(UC np->m_from));
@@ -564,9 +569,9 @@ get_map(wp, c)
 	cp = name = m_from;
 	*cp++ = c;
 	tn = first_map;
-	for (i=0; i < M_NAMELEN; i++) {
+	for (i = 0; i < M_NAMELEN; i++) {
 		*cp = '\0';
-		for (;;tn = tn->m_next) {
+		for (; ; tn = tn->m_next) {
 			if (tn == (smap_t *) NULL) {
 				pushmap(&name[1], cp - &name[1]);
 				return (NULL);
@@ -703,7 +708,7 @@ pretty_string(s)
 		free(str);
 	s1 = str = (Uchar *)malloc(3 *(unsigned)strlen((char *)s) + 1);
 	while (*s) {
-		if(isprint(*s)) {
+		if (isprint(*s)) {
 			*s1++ = *s++;
 			continue;
 		}
@@ -745,14 +750,14 @@ init_cursor_maps()
 	/*
 	 * Let getenv() simulate the behaviour of getcurenv().
 	 * We need TERMCAP=, TERMPATH=, HOME= and TERM=.
-	 * This allows us to use the same tgetent() for bah and ved
+	 * This allows us to use the same tgetent() for bsh and ved
 	 * and we may use -lxtermcap
 	 */
 	esav = environ;
 	environ = evarray;
-	if ((tname = getcurenv(termname)) != NULL
-					&& tgetent(NULL, tname) == 1) {
-		ev_insert(concat(termcapname, eql, tcgetbuf(),  NULL));
+	if ((tname = getcurenv(termname)) != NULL &&
+					tgetent(NULL, tname) == 1) {
+		ev_insert(concat(termcapname, eql, tcgetbuf(), (char *)NULL));
 		ku = tgetstr("ku", &sbp);		/* Corsor up */
 		kd = tgetstr("kd", &sbp);		/* Corsor down */
 		kr = tgetstr("kr", &sbp);		/* Corsor forward */
