@@ -1,13 +1,13 @@
-/* @(#)message.c	1.22 01/06/21 Copyright 1984 J. Schilling */
+/* @(#)message.c	1.23 04/03/12 Copyright 1984-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)message.c	1.22 01/06/21 Copyright 1984 J. Schilling";
+	"@(#)message.c	1.23 04/03/12 Copyright 1984-2004 J. Schilling";
 #endif
 /*
  *	Management routines for the system (status) line of the editor
  *	displayed at the top of the screen.
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -20,12 +20,12 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/**
+/*
  * Layout of the systemline:
  *
  * |.123456789.123456789.123456789.123456789.123456789.123456789.123456789...
@@ -66,12 +66,12 @@ static	char sccsid[] =
 LOCAL	Uchar	infostr[SYSLSIZE];		/* left most part of message */
 LOCAL	Uchar	namestr[2*INFOSIZE];		/* center part, name of file */
 LOCAL	Uchar	errorstr[INFOSIZE];		/* right part, error messages*/
-LOCAL	Uchar	numstr[NUMSIZE];		/* display of multiple	     */
-LOCAL	Uchar	takestr[TAKESIZE];		/* display of take buffer    */
-LOCAL	Uchar	DefInfostr[INFOSIZE];		/* default info string	     */
-LOCAL	Uchar	DefErrorstr[INFOSIZE-1];	/* default error string	     */
+LOCAL	Uchar	numstr[NUMSIZE];		/* display of multiple	    */
+LOCAL	Uchar	takestr[TAKESIZE];		/* display of take buffer   */
+LOCAL	Uchar	DefInfostr[INFOSIZE];		/* default info string	    */
+LOCAL	Uchar	DefErrorstr[INFOSIZE-1];	/* default error string	    */
 						/* may be prepended by a ' ' */
-						/* to create error message   */
+						/* to create error message  */
 
 EXPORT	BOOL	updatemsg = 0;			/* infostr is temporary */
 EXPORT	BOOL	updateerr = 0;			/* errorstr is temporary */
@@ -89,20 +89,20 @@ LOCAL	ecnt_t	maxmsgnum = (ecnt_t)1;	/* how big a displayed # can be */
 #define	takesize (nameplace-takeplace)	/* actual length of the takestring */
 #define	namesize (errorplace-nameplace)	/* actual length of the namestring */
 #define	errorsize (wp->llen-errorplace)	/* actual length of the errorstring */
-#define	nameerrsize (wp->llen-nameplace)/* actual length of the name+errorstring */
+#define	nameerrsize (wp->llen-nameplace) /* actual length of the name+errorstring */
 
 EXPORT	void	initmessage	__PR((ewin_t *wp));
 EXPORT	void	initmsgsize	__PR((ewin_t *wp));
-EXPORT	void	writemsg	__PR((ewin_t *wp, char* str, ...));
+EXPORT	void	writemsg	__PR((ewin_t *wp, char *str, ...));
 EXPORT	void	writenum	__PR((ewin_t *wp, ecnt_t num));
-EXPORT	void	writetake	__PR((ewin_t *wp, Uchar* str));
+EXPORT	void	writetake	__PR((ewin_t *wp, Uchar *str));
 EXPORT	void	namemsg		__PR((Uchar* name));
-EXPORT	void	writeerr	__PR((ewin_t *wp, char* str, ...));
-EXPORT	void	writeserr	__PR((ewin_t *wp, char* str, ...));
-LOCAL	void	_writeerr	__PR((ewin_t *wp, BOOL dobeep, char* str, va_list args));
-EXPORT	void	write_errno	__PR((ewin_t *wp, char* msg, ...));
-EXPORT	void	defaultinfo	__PR((ewin_t *wp, Uchar* str));
-EXPORT	void	defaulterr	__PR((ewin_t *wp, Uchar* str));
+EXPORT	void	writeerr	__PR((ewin_t *wp, char *str, ...));
+EXPORT	void	writeserr	__PR((ewin_t *wp, char *str, ...));
+LOCAL	void	_writeerr	__PR((ewin_t *wp, BOOL dobeep, char *str, va_list args));
+EXPORT	void	write_errno	__PR((ewin_t *wp, char *msg, ...));
+EXPORT	void	defaultinfo	__PR((ewin_t *wp, Uchar *str));
+EXPORT	void	defaulterr	__PR((ewin_t *wp, Uchar *str));
 LOCAL	void	errdefault	__PR((void));
 EXPORT	void	refreshmsg	__PR((ewin_t *wp));
 EXPORT	void	refreshsysline	__PR((ewin_t *wp));
@@ -158,7 +158,7 @@ initmsgsize(wp)
 	/*
 	 * Overflow bei Berechnung von maxmsgnum verhindern
 	 */
-	for (on=(ecnt_t)0, n=(ecnt_t)1, maxnumplaces=0;
+	for (on = (ecnt_t)0, n = (ecnt_t)1, maxnumplaces = 0;
 			n > 0 && n > on && maxnumplaces < NUMSIZE-1;
 							maxnumplaces++) {
 		on = n;
@@ -204,8 +204,8 @@ writemsg(wp, str, va_alist)
 	int	len = 0;
 
 	if (str == 0) {
-		strncpy(C infostr, C DefInfostr, sizeof(infostr));
-		infostr[sizeof(infostr)-1] = '\0';
+		strncpy(C infostr, C DefInfostr, sizeof (infostr));
+		infostr[sizeof (infostr)-1] = '\0';
 		updatemsg = 0;
 	} else if (*str == '\0') {
 		infostr[0] = '\0';
@@ -216,7 +216,7 @@ writemsg(wp, str, va_alist)
 #else
 		va_start(args);
 #endif
-		len = snprintf(C infostr, sizeof(infostr), "%r", str, args);
+		len = snprintf(C infostr, sizeof (infostr), "%r", str, args);
 		va_end(args);
 		updatemsg = 1;
 	}
@@ -265,8 +265,8 @@ writenum(wp, num)
 {
 	if (num < (ecnt_t)0)
 		numstr[0] = '\0';
-	else if (num<maxmsgnum)
-		snprintf(C numstr, sizeof(numstr), " #:%lld", (Llong)num);
+	else if (num < maxmsgnum)
+		snprintf(C numstr, sizeof (numstr), " #:%lld", (Llong)num);
 	else
 		strcpy(C numstr, " #:BIG");
 	MOVE_CURSOR_ABS(wp, 0, numplace);
@@ -286,7 +286,7 @@ writetake(wp, str)
 	ewin_t	*wp;
 	Uchar	*str;
 {
-	snprintf(C takestr, sizeof(takestr), " \\:%s", str);
+	snprintf(C takestr, sizeof (takestr), " \\:%s", str);
 	MOVE_CURSOR_ABS(wp, 0, takeplace);
 	printfield(takestr, takesize);
 	setcursor(wp);
@@ -303,7 +303,7 @@ EXPORT void
 namemsg(name)
 	Uchar	*name;
 {
-	snprintf(C namestr, sizeof(namestr), " %s", C name);
+	snprintf(C namestr, sizeof (namestr), " %s", C name);
 }
 
 /*---------------------------------------------------------------------------
@@ -402,7 +402,7 @@ _writeerr(wp, dobeep, str, args)
 			errorstr[0] = '\0';
 			updateerr = 1;
 		} else {
-			len = snprintf(C errorstr, sizeof(errorstr), " %r",
+			len = snprintf(C errorstr, sizeof (errorstr), " %r",
 								str, args);
 			if (dobeep)
 				ringbell();
@@ -465,7 +465,7 @@ write_errno(wp, msg, va_alist)
 #else
 	va_start(args);
 #endif
-	len = snprintf(buf, sizeof(buf), "%r: %s", msg, args, errstr);
+	len = snprintf(buf, sizeof (buf), "%r: %s", msg, args, errstr);
 	va_end(args);
 
 	if (len <= nameerrsize) {
@@ -478,7 +478,7 @@ write_errno(wp, msg, va_alist)
 #else
 	va_start(args);
 #endif
-	snprintf(buf, sizeof(buf), "(%d) %r: %s", err, msg, args, errstr);
+	snprintf(buf, sizeof (buf), "(%d) %r: %s", err, msg, args, errstr);
 	va_end(args);
 	writeerr(wp, buf);
 }
@@ -500,7 +500,7 @@ defaultinfo(wp, str)
 	if (str == NULL)
 		DefInfostr[0] = '\0';
 	else
-		snprintf(C DefInfostr, sizeof(DefInfostr), "%s", str);
+		snprintf(C DefInfostr, sizeof (DefInfostr), "%s", str);
 	writemsg(wp, C DefInfostr);
 
 }
@@ -519,11 +519,11 @@ defaulterr(wp, str)
 	ewin_t	*wp;
 	Uchar	*str;
 {
-	if (str==0) {
+	if (str == 0) {
 		DefErrorstr[0] = '\0';
 		writeerr(wp, "");
 	} else {
-		snprintf(C DefErrorstr, sizeof(DefErrorstr), "%s", str);
+		snprintf(C DefErrorstr, sizeof (DefErrorstr), "%s", str);
 		writeerr(wp, C DefErrorstr);
 	}
 }
@@ -548,7 +548,7 @@ errdefault()
 		 * the filename.
 		 */
 		errorstr[0] = ' ';
-		strcpy(C &errorstr[1], C DefErrorstr);/* no overflow (same size)*/
+		strcpy(C &errorstr[1], C DefErrorstr); /* no overflow (same size)*/
 
 	}
 }
@@ -604,8 +604,8 @@ write_systemline(wp)
 	ewin_t	*wp;
 {
 	if (updatemsg) {
-		strncpy(C infostr, C DefInfostr, sizeof(infostr));
-		infostr[sizeof(infostr)-1] = '\0';
+		strncpy(C infostr, C DefInfostr, sizeof (infostr));
+		infostr[sizeof (infostr)-1] = '\0';
 		updatemsg = 0;
 	}
 	if (updateerr) {
