@@ -1,12 +1,12 @@
-/* @(#)quitcmds.c	1.53 01/11/18 Copyright 1984 J. Schilling */
+/* @(#)quitcmds.c	1.59 04/03/13 Copyright 1984-1989, 1994-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)quitcmds.c	1.53 01/11/18 Copyright 1984 J. Schilling";
+	"@(#)quitcmds.c	1.59 04/03/13 Copyright 1984-1989, 1994-2004 J. Schilling";
 #endif
 /*
  *	Commands that deal with exiting the editor in a clean state
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984-1989, 1994-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -19,9 +19,9 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #include "ved.h"
@@ -57,7 +57,7 @@ bakbuf(wp, force)
 	ewin_t	*wp;
 	BOOL	force;
 {
-		 Uchar	backup[FNAMESIZE+4];	/* += strlen(".bak");	*/
+		Uchar	backup[FNAMESIZE+4];	/* += strlen(".bak");	*/
 	register Uchar	*t;
 	register Uchar	*s;
 	int	 oldmodes;
@@ -86,22 +86,16 @@ bakbuf(wp, force)
 		t = s + DIRSIZE - 4;
 #endif
 
-	strcpy(C t, ".bak");		/* add the the ".bak" extension     */
-	unlink(C backup);		/* delete the old version of backup */
-	if (link(C wp->curfile, C backup) < 0) {/* rename old curfile to backup */
+	strcpy(C t, ".bak");		/* add the the ".bak" extension	    */
+	if (rename(C wp->curfile, C backup) < 0) { /* rename old curfile to backup */
 		backpresent = FALSE;
 		if (geterrno() != ENOENT)
 			writemsg(wp, "Can't make *.bak file");
-	} else {
-		unlink(C wp->curfile);
 	}
 
 	if (!writebuf(wp, force)) {	/* if writeback failed ... */
-		if (backpresent){	/* rename backup to orig file name */
-			unlink(C wp->curfile);
-			if (link(C backup, C wp->curfile) >= 0)
-				unlink(C backup);
-		}
+		if (backpresent)	/* rename backup to orig file name */
+			rename(C backup, C wp->curfile);
 		return (FALSE);
 	}
 	if (oldmodes >= 0)
@@ -122,6 +116,10 @@ writebuf(wp, force)
 {
 	FILE	*outfile;
 	BOOL	ret = TRUE;
+#ifdef	HAVE_FSYNC
+	int	err;
+	int	cnt;
+#endif
 
 	if ((!force || ReadOnly > 1) && wrtcheck(wp, TRUE) == FALSE)
 		return (FALSE);
@@ -148,7 +146,16 @@ writebuf(wp, force)
 	if (fflush(outfile) != 0)
 		ret = FALSE;
 #ifdef	HAVE_FSYNC
-	if (fsync(fdown(outfile)) != 0)
+	err = 0;
+	cnt = 0;
+	do {
+		if (fsync(fdown(outfile)) != 0)
+			err = geterrno();
+
+		if (err == EINVAL)
+			err = 0;
+	} while (err == EINTR && ++cnt < 10);
+	if (err != 0)
 		ret = FALSE;
 #endif
 	if (fclose(outfile) != 0)
@@ -169,7 +176,7 @@ vbackup(wp)
 {
 	int	c;
 
-	switch(c = getcmdchar(wp, NULL, "BACKUP?(Y/W/N/F/!) ")) {
+	switch (c = getcmdchar(wp, NULL, "BACKUP?(Y/W/N/F/!) ")) {
 
 	default:
 		abortmsg(wp);
@@ -212,7 +219,7 @@ vquit(wp)
 	if (wp->modflg)
 		writeerr(wp, "FILE MODIFIED!");
 
-	switch(c = getcmdchar(wp, NULL, "QUITTING. PUT EDITS?(Y/W/N/F/!) ")) {
+	switch (c = getcmdchar(wp, NULL, "QUITTING. PUT EDITS?(Y/W/N/F/!) ")) {
 
 	default:
 		abortmsg(wp);
@@ -267,7 +274,7 @@ vsuspend(wp)
 	if (wp->modflg)
 		writeerr(wp, "FILE MODIFIED!");
 
-	switch(c = getcmdchar(wp, NULL, "SUSPENDING. PUT EDITS?(Y/W/N/F/!) ")) {
+	switch (c = getcmdchar(wp, NULL, "SUSPENDING. PUT EDITS?(Y/W/N/F/!) ")) {
 
 	default:
 		abortmsg(wp);
@@ -327,9 +334,9 @@ suspend(p)
 	int	p;
 {
 #ifdef	SIGSTOP
-	return kill(p, SIGSTOP);
+	return (kill(p, SIGSTOP));
 #else
-	raise("suspend not implemented", 0L);
+	raisecond("suspend not implemented", 0L);
 #endif
 }
 #endif
