@@ -1,12 +1,12 @@
-/* @(#)screen.c	1.37 00/12/27 Copyright 1984 J. Schilling */
+/* @(#)screen.c	1.38 04/03/12 Copyright 1984-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)screen.c	1.37 00/12/27 Copyright 1984 J. Schilling";
+	"@(#)screen.c	1.38 04/03/12 Copyright 1984-2004 J. Schilling";
 #endif
 /*
  *	Screen update functions for VED
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -19,15 +19,15 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*
  * The functions below are responsible for the fast screen update of VED.
  * Main implementation goal was to make the screen uptate fast, ergonomic
- * and free of jerks. The screen update of vi is not aceptable since 
+ * and free of jerks. The screen update of vi is not aceptable since
  * inserting line by line makes the screen hard to read while scrolling.
  * The screen update of emacs shows you jerking status lines and for that
  * reason is hard to read too.
@@ -42,8 +42,8 @@ static	char sccsid[] =
  * of VED by doing block insert lines, but are slower (emacs spends 4 times
  * the CPU time in its equivalent screen update package) than VED.
  * Take extrame care when doing any modifications on this module.
- * The basic functionality has not been changed since 1986. Although 
- * many minor changes (markwrap and some cursor positioning problems) 
+ * The basic functionality has not been changed since 1986. Although
+ * many minor changes (markwrap and some cursor positioning problems)
  * have been done to make it behave more correctly.
  *
  * The basic idea is to use no retained memory to compare the current and
@@ -119,7 +119,7 @@ static	char sccsid[] =
  *
  * Da der ved versucht die Terminalabhngigen Dinge mglichst vorsichtig zu
  * verwenden, scheidet daher die letzte Methode aus.
- * 
+ *
  * N.B.: Der vi ist auf maximale Performance bei 300 Baud optimiert, der
  *	 ved auf maximale Performance bei hohen Datenraten.
  */
@@ -133,8 +133,8 @@ static	char sccsid[] =
 #ifdef	DEBUG
 #define	DBG(a)		(cdbg a)
 #define	FDBG(a)		(flush(), cdbg a)
-#define	SDBG(a)		(cdbg a , sleep(2))
-#define	FSDBG(a)	(flush(), cdbg a , sleep(2))
+#define	SDBG(a)		(cdbg a, sleep(2))
+#define	FSDBG(a)	(flush(), cdbg a, sleep(2))
 #else
 #define	DBG(a)
 #define	FDBG(a)
@@ -148,10 +148,10 @@ EXPORT	cpos_t	cpos;		/* real pos of cursor on screen hp mapped    */
 #define	MARKWRAP
 /* XXX markwrap ist noch nicht implementiert */
 
-LOCAL	BOOL	nl_ostop;	/* stop output past wrap marker '\\'	     */
+LOCAL	BOOL	nl_ostop;	/* stop output past wrap marker '\\'	    */
 
-extern	Uchar	csize[];	/* The character sizes table		     */
-extern	Uchar	*ctab[];	/* The character string table		     */
+extern	Uchar	csize[];	/* The character sizes table		    */
+extern	Uchar	*ctab[];	/* The character string table		    */
 
 /*
  * XXX static beseitigen! -> automatic.
@@ -169,15 +169,15 @@ LOCAL	int	passoffset = 0;		/* set with findpos() and left alone */
  * return the next character in the buffer on each call.
  */
 
-#define getnext(wp)	rpasslink->cont[rpassoffset++];		\
+#define	getnext(wp)	rpasslink->cont[rpassoffset++];		\
 									\
-	while (rpassoffset >= rpasslink->size){				\
+	while (rpassoffset >= rpasslink->size) {			\
 		rpassoffset -= rpasslink->size;				\
 		rpasslink = rpasslink->next;				\
 		readybuffer(wp, rpasslink);				\
 	}
 
-#define peeknext()	rpasslink->cont[rpassoffset]
+#define	peeknext()	rpasslink->cont[rpassoffset]
 
 /*
  * On a Motorola 68000 there is no divsll and even on an 68020
@@ -204,7 +204,7 @@ LOCAL	int	passoffset = 0;		/* set with findpos() and left alone */
  * This is true if there was a linewrap and we are at the start of the line or
  * if folding the lines would take us to the same virtual horizontal position.
  */
-#define	nomatch(hp1,hp2) (linewrap ? (hp1) || (hp2) : \
+#define	nomatch(hp1, hp2) (linewrap ? (hp1) || (hp2) : \
 				modu(hp1, wp->llen) != modu(hp2, wp->llen))
 
 LOCAL	epos_t	lastdot = -1L;
@@ -326,7 +326,7 @@ LOCAL epos_t
 getnewwindow(wp)
 	ewin_t	*wp;
 {
-		 cpos_t	c;
+		cpos_t	c;
 	register epos_t	newwin;
 	register epos_t	win = wp->dot;
 	register int	vpos = 1;
@@ -341,7 +341,7 @@ getnewwindow(wp)
 	do {
 		c.vp = 1;
 		c.hp = 0;
-		newwin = revline(wp, win, (ecnt_t)2);/* eine Zeile zurueck */
+		newwin = revline(wp, win, (ecnt_t)2); /* eine Zeile zurueck */
 		countpos(wp, newwin, win, &c);
 		win = newwin;
 		vpos += realvp(wp, &c) - 1;
@@ -480,13 +480,13 @@ setcursor(wp)
 
 /*---------------------------------------------------------------------------
 |
-| Map cp->vp/cp->hp position description into description of the form vp/0 
+| Map cp->vp/cp->hp position description into description of the form vp/0
 |
 +---------------------------------------------------------------------------*/
 
 LOCAL void
 mappos(wp, cp)
-		 ewin_t	*wp;
+		ewin_t	*wp;
 	register cpos_t	*cp;
 {
 	cp->vp = realvp(wp, cp) + 1;
@@ -503,9 +503,9 @@ mappos(wp, cp)
 
 EXPORT epos_t
 countpos(wp, old, new, cp)
-		 ewin_t	*wp;
-		 epos_t	old;
-		 epos_t	new;
+		ewin_t	*wp;
+		epos_t	old;
+		epos_t	new;
 	register cpos_t	*cp;
 {
 	register headr_t *rpasslink;	/* state for getnext - these should */
@@ -606,7 +606,7 @@ getcol(wp, begin, maxcol, cp)
 
 EXPORT epos_t
 findcol(wp, col, begin)
-		 ewin_t	*wp;
+		ewin_t	*wp;
 	register int	col;
 	register epos_t	begin;
 {
@@ -627,8 +627,8 @@ findcol(wp, col, begin)
 	return (begin);
 }
 
-LOCAL	int	tabcnt;		/* # of tabs found by last findmatch call  */
-LOCAL	BOOL	linewrap;	/* The changes caused a diffrent vpos      */
+LOCAL	int	tabcnt;		/* # of tabs found by last findmatch call */
+LOCAL	BOOL	linewrap;	/* The changes caused a diffrent vpos    */
 
 /*---------------------------------------------------------------------------
 |
@@ -639,8 +639,8 @@ LOCAL	BOOL	linewrap;	/* The changes caused a diffrent vpos      */
 
 LOCAL epos_t
 findmatch(wp, begin, a, b)
-		 ewin_t	*wp;
-		 epos_t	begin;
+		ewin_t	*wp;
+		epos_t	begin;
 	register cpos_t	*a;
 	register cpos_t	*b;
 {
@@ -717,7 +717,7 @@ dispup(wp, old, new)
 {
 	FDBG(("  dispup (%lld, %lld) P: %d.%d %s", (Llong)old, (Llong)new,
 					cpos.vp, cpos.hp,
-					(new > old)? "Delete":"Insert" ));
+					(new > old)? "Delete":"Insert"));
 
 	if ((gotshorter = (new > old)) != 0) {
 		dispdel(wp, old, new);
@@ -796,8 +796,8 @@ dispdel(wp, old, new)
 	 */
 	if ((size = realvp(wp, &o) - realvp(wp, &n)) > 0 && new < wp->eof) {
 		if (f_del_line && size>>1 <= wp->psize/3+1 &&
-						size+cpos.vp < wp->psize-1
-						&& cpos.vp < wp->psize) {
+		    size+cpos.vp < wp->psize-1 &&
+		    cpos.vp < wp->psize) {
 			/*
 			 * First redraw to end of current screen line.
 			 */
@@ -875,7 +875,7 @@ dispdel(wp, old, new)
 		/*
 		 * There is no delele-line feature or we don't want
 		 * to use it, redraw to end.
-	 	 */
+		 */
 		old = wp->eof;
 	}
 	typescn(wp, new, col, old);
@@ -962,8 +962,8 @@ dispins(wp, old, new)
 	 * require that at least one old line remains on screen.
 	 */
 	if ((size = (realvp(wp, &n)-realvp(wp, &o)))*2 > wp->psize ||
-			size+cpos.vp >= wp->psize-1
-			|| old == wp->eof) {
+			size+cpos.vp >= wp->psize-1 ||
+			old == wp->eof) {
 		typescn(wp, new, col, wp->eof);		/* Retype rest */
 
 		FSDBG(("TS1dispins(%lld, %lld) P: %d.%d",
@@ -1009,7 +1009,7 @@ dispins(wp, old, new)
 
 EXPORT int
 realvp(wp, cp)
-		 ewin_t	*wp;
+		ewin_t	*wp;
 	register cpos_t	*cp;
 {
 #ifdef	MARKWRAP
@@ -1032,7 +1032,7 @@ realvp(wp, cp)
 
 EXPORT int
 realhp(wp, cp)
-		 ewin_t	*wp;
+	ewin_t	*wp;
 	cpos_t	*cp;
 {
 	register int	h = cp->hp;
@@ -1083,7 +1083,7 @@ LOCAL	int	lcol;			/* Remembered last typed column. */
 
 LOCAL epos_t
 typescx(wp, begin, col, end)
-		 ewin_t	*wp;
+		ewin_t	*wp;
 	register epos_t	begin;
 		int	col;
 		epos_t	end;
@@ -1169,7 +1169,7 @@ typescx(wp, begin, col, end)
  */
 LOCAL void
 typerest(wp, begin, cp)
-		 ewin_t	*wp;
+		ewin_t	*wp;
 	register epos_t	begin;
 	register cpos_t	*cp;
 {
@@ -1178,7 +1178,7 @@ typerest(wp, begin, cp)
 	register Uchar	c;		/* wrapping character		    */
 	register Uchar	*s;		/* string to output for 'c'	    */
 	register int	rest;		/* number of untyped chars in 'c'   */
-		 int	p;
+		int	p;
 
 	/*
 	 * Wenn die Zeile wickelt, dann ist realvp(cp) mindestens auf psize+1
@@ -1234,10 +1234,10 @@ out:
 
 EXPORT void
 typescreen(wp, begin, col, end)
-		 ewin_t	*wp;
+		ewin_t	*wp;
 	register epos_t	begin;
-		 int	col;
-		 epos_t	end;
+		int	col;
+		epos_t	end;
 {
 	gotshorter	= TRUE;
 	linewrap	= FALSE;
@@ -1346,9 +1346,9 @@ outnl(wp, nlflg)
 	BOOL	nlflg;
 {
 	if (!b_auto_right_margin || cpos.vp < wp->psize || cpos.hp < wp->llen)
-	  	addchar((Uchar) (wp->visible ? '$' : ' '));
+		addchar((Uchar) (wp->visible ? '$' : ' '));
 	else
-	  	siaddchar(wp, (Uchar) (wp->visible ? '$' : ' '));
+		siaddchar(wp, (Uchar) (wp->visible ? '$' : ' '));
 
 	if (b_auto_right_margin && cpos.hp >= wp->llen) {
 		MOVE_CURSOR_ABS(wp, cpos.vp, cpos.hp);
@@ -1443,14 +1443,14 @@ insert_pad(wp, size)
 	ewin_t	*wp;
 	int	size;
 {
-		 char	padding[256];
+		char	padding[256];
 	register int	idx;
 	register int	amt = size;
 
 	while (size > 0) {
-		if (amt >= sizeof(padding))
-			amt = sizeof(padding) - 1;
-			
+		if (amt >= sizeof (padding))
+			amt = sizeof (padding) - 1;
+
 		for (idx = 0; idx < amt; )
 			padding[idx++] = ' ';
 		padding[idx] = '\0';
