@@ -1,13 +1,13 @@
-/* @(#)storage.c	1.41 01/06/20 Copyright 1984 J. Schilling */
+/* @(#)storage.c	1.45 04/03/13 Copyright 1984-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)storage.c	1.41 01/06/20 Copyright 1984 J. Schilling";
+	"@(#)storage.c	1.45 04/03/13 Copyright 1984-2004 J. Schilling";
 #endif
 /*
  *	Storage management based on the paged virtual memory
  *	provided by buffer.c
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*
@@ -48,7 +48,7 @@ static	char sccsid[] =
  *
  * To speed up findpos() on very long files, we maintain an 'anker' that
  * is at or close before the start or the current screen window. This allows
- * findpos() to work relative to this 'anker'. The variables that are 
+ * findpos() to work relative to this 'anker'. The variables that are
  * used to maintain this 'anker' are 'winlink', 'winpos' and 'winoff'.
  */
 
@@ -74,9 +74,6 @@ static	char sccsid[] =
 #	include <error.h>
 #else
 #	include	<errno.h>
-#ifndef	HAVE_ERRNO_DEF
-extern	int	errno;
-#endif
 #endif
 
 #define	wp_gaplink(p)	((headr_t *)((p)->gaplink))
@@ -86,25 +83,25 @@ EXPORT	void	insert		__PR((ewin_t *wp, Uchar* str, long size));
 EXPORT	void	delete		__PR((ewin_t *wp, epos_t size));
 EXPORT	void	rubout		__PR((ewin_t *wp, epos_t size));
 EXPORT	BOOL	loadfile	__PR((ewin_t *wp, Uchar* filename, BOOL newdefault));
-EXPORT	BOOL	savefile	__PR((ewin_t *wp, epos_t begin, epos_t end, FILE * f, char* name));
-EXPORT	BOOL	backsavefile	__PR((ewin_t *wp, epos_t begin, epos_t end, FILE * f, char* name));
+EXPORT	BOOL	savefile	__PR((ewin_t *wp, epos_t begin, epos_t end, FILE * f, char *name));
+EXPORT	BOOL	backsavefile	__PR((ewin_t *wp, epos_t begin, epos_t end, FILE * f, char *name));
 EXPORT	void	getfile		__PR((ewin_t *wp, FILE * f, epos_t size, char *name));
 EXPORT	void	backgetfile	__PR((ewin_t *wp, FILE * f, epos_t size, char *name));
 LOCAL	void	reversebuffer	__PR((Uchar* from, Uchar* to, long size));
-EXPORT	int	extract		__PR((ewin_t *wp, epos_t begin, Uchar* str, int size));
-EXPORT	int	extr_line	__PR((ewin_t *wp, epos_t begin, char* str, int size));
-EXPORT	int	retractline	__PR((ewin_t *wp, epos_t begin, char* str, int size));
+EXPORT	int	extract		__PR((ewin_t *wp, epos_t begin, Uchar *str, int size));
+EXPORT	int	extr_line	__PR((ewin_t *wp, epos_t begin, char *str, int size));
+EXPORT	int	retractline	__PR((ewin_t *wp, epos_t begin, char *str, int size));
 LOCAL	void	movegap		__PR((ewin_t *wp, epos_t pos));
 EXPORT	void	clearifwpos	__PR((ewin_t *wp, headr_t *this));
 EXPORT	void	clearwpos	__PR((ewin_t *wp));
 EXPORT	void	backwpos	__PR((ewin_t *wp));
 EXPORT	void	findwpos	__PR((ewin_t *wp, epos_t new));
-EXPORT	void	findpos		__PR((ewin_t *wp, epos_t pos, headr_t ** returnlinkp, int* returnoff));
+EXPORT	void	findpos		__PR((ewin_t *wp, epos_t pos, headr_t ** returnlinkp, int *returnoff));
 #ifdef	FASTPOS
 #ifdef	CHECKPOS
-LOCAL	void	ckfindpos	__PR((ewin_t *wp, epos_t pos, headr_t ** returnlinkp, int* returnoff));
+LOCAL	void	ckfindpos	__PR((ewin_t *wp, epos_t pos, headr_t ** returnlinkp, int *returnoff));
 #endif
-LOCAL	void	rfindpos	__PR((ewin_t *wp, epos_t pos, headr_t ** returnlinkp, int* returnoff));
+LOCAL	void	rfindpos	__PR((ewin_t *wp, epos_t pos, headr_t ** returnlinkp, int *returnoff));
 #endif
 
 /*
@@ -113,7 +110,7 @@ LOCAL	void	rfindpos	__PR((ewin_t *wp, epos_t pos, headr_t ** returnlinkp, int* r
  */
 EXPORT void
 insert(wp, str, size)
-		 ewin_t	*wp;
+		ewin_t	*wp;
 	register Uchar	*str;
 	register long	size;
 {
@@ -200,7 +197,7 @@ delete(wp, size)
 		next->cont += amount;
 		/*
 		 * We are modifying next->cont and thus must set the MODIFIED
-		 * flag in the header. This is needed because we swap out from 
+		 * flag in the header. This is needed because we swap out from
 		 * linkp->cont and remove any leading gap when we swap in.
 		 * If we don't want to set the MODIFIED flag here, we must
 		 * always swap out the complete buffer and restore the old
@@ -234,7 +231,7 @@ rubout(wp, size)
 	epos_t	size;
 {
 	register epos_t	n;
-		 epos_t	savedot = wp->dot;
+		epos_t	savedot = wp->dot;
 	register int	amount;
 
 	if (size > wp->dot)
@@ -283,7 +280,7 @@ loadfile(wp, filename, newdefault)
 	FILE	*infile;
 	Uchar	str[BUFSIZ < 8192 ? 8192 : BUFSIZ];
 	long	size;
-#ifdef	IS_CYGWIN
+#if	defined(IS_CYGWIN) || defined(__DJGPP__)
 	BOOL	retry = FALSE;
 #endif
 
@@ -310,14 +307,14 @@ loadfile(wp, filename, newdefault)
 		return (FALSE);
 	}
 	file_raise(infile, FALSE);
-#ifdef	IS_CYGWIN
+#if	defined(IS_CYGWIN) || defined(__DJGPP__)
 again:
 #endif
-	while ((size = readsyserr(wp, infile, str, sizeof str, UC "FILE")) > 0) {
+	while ((size = readsyserr(wp, infile, str, sizeof (str), UC "FILE")) > 0) {
 		insert(wp, str, size);
 	}
 	if (size < 0) {
-#ifdef	IS_CYGWIN
+#if	defined(IS_CYGWIN) || defined(__DJGPP__)
 		/*
 		 * On Cygwin, we cannot lock correctly.
 		 * Locks are on a fd base not on a process base.
@@ -340,7 +337,7 @@ again:
 		fclose(infile);
 		return (FALSE);
 	}
-#ifdef	IS_CYGWIN
+#if	defined(IS_CYGWIN) || defined(__DJGPP__)
 	if (newdefault && !retry && wp->curfd >= 0) {
 		write_errno(wp, "LOCK WORKED!");
 		sleep(2);
@@ -377,16 +374,16 @@ savefile(wp, begin, end, f, name)
 	char	*name;
 {
 	register headr_t *linkp = wp->bhead;
-		 headr_t *passlinkp;
+		headr_t *passlinkp;
 	register int	amount;
-		 int	pos = 0;
-		 int	nextsize;
-		 Uchar	*from;
+		int	pos = 0;
+		int	nextsize;
+		Uchar	*from;
 
 #ifdef	JOS
 	getpid();
 #else
-	errno = 0;		/* Damit write_errno korrekt arbeitet */
+	seterrno(0);		/* Damit write_errno korrekt arbeitet */
 #endif
 
 	if (end >= wp->eof)
@@ -428,7 +425,7 @@ backsavefile(wp, begin, end, f, name)
 	char	*name;
 {
 	register headr_t *linkp;
-		 headr_t *passlinkp;
+		headr_t *passlinkp;
 	register int	amount;
 		Uchar	buf[BUFFERSIZE];
 	int pos = 0;
@@ -440,7 +437,7 @@ backsavefile(wp, begin, end, f, name)
 #ifdef	JOS
 	getpid();
 #else
-	errno = 0;		/* Damit write_errno korrekt arbeitet */
+	seterrno(0);		/* Damit write_errno korrekt arbeitet */
 #endif
 
 	if (end > wp->eof)
@@ -474,7 +471,7 @@ backsavefile(wp, begin, end, f, name)
 			nextsize = linkp->size;
 		}
 	}
-	return(fflush(f) != EOF);
+	return (fflush(f) != EOF);
 }
 
 /*
@@ -489,8 +486,8 @@ getfile(wp, f, size, name)
 	char	*name;
 {
 	Uchar	buf[BUFSIZ];
-	long 	left;
-	long	this;
+	epos_t 	left;
+	int	this;
 	long	result;
 	register ecnt_t	n = wp->curnum;
 	epos_t	save = wp->dot;
@@ -500,10 +497,11 @@ getfile(wp, f, size, name)
 
 	while (--n >= 0) {
 		lseek(fdown(f), (off_t)0, SEEK_SET);
-		for(left = size; left > 0;) {
-			this = left;
-			if (this > sizeof (buf))
+		for (left = size; left > 0; ) {
+			if (left > sizeof (buf))
 				this = sizeof (buf);
+			else
+				this = (int)left;
 			if ((result = readsyserr(wp, f, buf, this, UC name)) < 0)
 				break;
 			insert(wp, buf, result);
@@ -539,10 +537,11 @@ backgetfile(wp, f, size, name)
 		return;
 
 	while (--n >= 0) {
-		for(left = size; left > 0;) {
-			this = left;
-			if (this > sizeof (buf))
+		for (left = size; left > 0; ) {
+			if (left > sizeof (buf))
 				this = sizeof (buf);
+			else
+				this = (int)left;
 			left -= this;
 			lseek(fdown(f), (off_t)left, SEEK_SET);
 			if ((result = readsyserr(wp, f, buf, this, UC name)) < 0)
@@ -562,7 +561,7 @@ LOCAL void
 reversebuffer(from, to, size)
 	register Uchar	*from;
 	register Uchar	*to;
-		 long	size;
+		long	size;
 {
 	to += (size-1);
 	while (--size >= 0)
@@ -573,7 +572,7 @@ reversebuffer(from, to, size)
  * Extract a portion of the buffer memory.
  * Fill in up to 'size' characters and return the amount of characters read.
  * NOTE: a NULL byte is added to the extracted string so it must be able
- * 	 to hold up to size + 1 characters.
+ *	 to hold up to size + 1 characters.
  */
 EXPORT int
 extract(wp, begin, str, size)
@@ -625,7 +624,7 @@ extract(wp, begin, str, size)
  * stop after extracting a new-line character.
  * Fill in up to 'size' characters and return the amount of characters read.
  * NOTE: a NULL byte is added to the extracted string so it must be able
- * 	 to hold up to size + 1 characters.
+ *	 to hold up to size + 1 characters.
  */
 EXPORT int
 extr_line(wp, begin, str, size)
@@ -656,7 +655,7 @@ extr_line(wp, begin, str, size)
 		amount = min(size, linksize);
 		while (amount-- > 0) {
 			size--, length++;
-			if ( (*str++ = *from++) == '\n') {
+			if ((*str++ = *from++) == '\n') {
 				size = 0;
 				break;
 			}
@@ -682,7 +681,7 @@ extr_line(wp, begin, str, size)
  * to 'extr_line' and allow symmetrical behavior in search functions.
  * The new-line that was found before 'begin' is not included.
  * NOTE: a NULL byte is added to the extracted string so it must be able
- * 	 to hold up to size + 1 characters.
+ *	 to hold up to size + 1 characters.
  */
 EXPORT int
 retractline(wp, begin, str, size)
@@ -833,7 +832,7 @@ findwpos(new)
  */
 EXPORT void
 findpos(wp, pos, returnlinkp, returnoff)
-		 ewin_t	*wp;
+		ewin_t	*wp;
 	register epos_t	pos;
 	headr_t		**returnlinkp;	/* To return found link header */
 	int		*returnoff;	/* To return found link offset */
@@ -953,12 +952,12 @@ checkpos:
 #ifdef	CHECKPOS
 /*
  * Find link pointer and offset in found buffer for 'pos'.
- * This is the old version that may be called after the new one and 
+ * This is the old version that may be called after the new one and
  * checks for diffs.
  */
 LOCAL void
 ckfindpos(wp, pos, returnlinkp, returnoff)
-		 ewin_t	*wp;
+		ewin_t	*wp;
 	register epos_t	pos;
 	headr_t		**returnlinkp;	/* To return found link header */
 	int		*returnoff;	/* To return found link offset */
@@ -988,7 +987,7 @@ ckfindpos(wp, pos, returnlinkp, returnoff)
 	if (*returnlinkp != linkp || *returnoff != pos) {
 		cdbg("DIFF: %X o%X %d o%d caller: %X", *returnlinkp, linkp, *returnoff, pos,
 			getcaller());
-		writeerr(wp, "DIFF: %X o%X %d o%d", *returnlinkp, linkp, *returnoff, pos);sleep(10);
+		writeerr(wp, "DIFF: %X o%X %d o%d", *returnlinkp, linkp, *returnoff, pos); sleep(10);
 	}
 	*returnlinkp = linkp;
 	*returnoff = (int)pos;
@@ -1001,7 +1000,7 @@ ckfindpos(wp, pos, returnlinkp, returnoff)
  */
 LOCAL void
 rfindpos(wp, pos, returnlinkp, returnoff)
-		 ewin_t	*wp;
+		ewin_t	*wp;
 	register epos_t pos;
 	headr_t		**returnlinkp;	/* To return found link header */
 	int		*returnoff;	/* To return found link offset */
