@@ -1,12 +1,12 @@
-/* @(#)ttycmds.c	1.17 00/12/27 Copyright 1984 J. Schilling */
+/* @(#)ttycmds.c	1.19 04/03/12 Copyright 1984-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)ttycmds.c	1.17 00/12/27 Copyright 1984 J. Schilling";
+	"@(#)ttycmds.c	1.19 04/03/12 Copyright 1984-2004 J. Schilling";
 #endif
 /*
  *	Lower layer support routines for terminal.c
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -19,9 +19,9 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*
@@ -66,8 +66,8 @@ EXPORT	void (*TTYup)		__PR((int))	= 0;	/* cursor up */
 EXPORT	void (*TTYdown)		__PR((int))	= 0;	/* cursor down */
 EXPORT	void (*TTYleft)		__PR((int))	= 0;	/* cursor left */
 EXPORT	void (*TTYright)	__PR((int))	= 0;	/* cursor right */
-EXPORT	void (*TTYcursor)	__PR((int y, int x))= 0;/* move cursor abs */
-EXPORT	void (*TTYsscroll)	__PR((int, int))= 0;	/* set scroll region */
+EXPORT	void (*TTYcursor)	__PR((int y, int x)) = 0; /* move cursor abs */
+EXPORT	void (*TTYsscroll)	__PR((int, int)) = 0;	/* set scroll region */
 EXPORT	void (*TTYsup)		__PR((int))	= 0;	/* scroll up */
 EXPORT	void (*TTYsdown)	__PR((int))	= 0;	/* scroll down */
 
@@ -207,12 +207,12 @@ LOCAL	char	**tfkeys[] = {
 		&K10, &K11, &K12, &K13, &K14, &K15, &K16, &K17, &K18, &K19,
 		};
 
-EXPORT	char*	tty_start	__PR((int (*)(int c)));
-LOCAL	void	tputstr		__PR((char* s));
-EXPORT	char**	tty_entry	__PR((void));
+EXPORT	char *	tty_start	__PR((int (*)(int c)));
+LOCAL	void	tputstr		__PR((char *s));
+EXPORT	char **	tty_entry	__PR((void));
 EXPORT	void	tty_init	__PR((void));
 EXPORT	void	tty_term	__PR((void));
-EXPORT	char*	tty_fkey	__PR((int n));
+EXPORT	char *	tty_fkey	__PR((int n));
 EXPORT	int	tty_pagesize	__PR((void));
 EXPORT	int	tty_linelength	__PR((void));
 LOCAL	void	cur_abs		__PR((int y, int x));
@@ -232,15 +232,15 @@ LOCAL	void	del_c_S		__PR((int n));
 LOCAL	void	del_c_M		__PR((int n));
 LOCAL	void	del_l_S		__PR((int n));
 LOCAL	void	del_l_M		__PR((int n));
-LOCAL	void	ins_c_S		__PR((char* str));
-LOCAL	void	ins_c_M		__PR((char* str));
-LOCAL	void	ins_str		__PR((char* str));
+LOCAL	void	ins_c_S		__PR((char *str));
+LOCAL	void	ins_c_M		__PR((char *str));
+LOCAL	void	ins_str		__PR((char *str));
 LOCAL	void	ins_l_S		__PR((int n));
 LOCAL	void	ins_l_M		__PR((int n));
-LOCAL	void	alt_S_Svideo	__PR((char* str));
-LOCAL	void	alt_S_video	__PR((char* str));
-LOCAL	void	alt_B_video	__PR((char* str));
-LOCAL	void	alt_U_video	__PR((char* str));
+LOCAL	void	alt_S_Svideo	__PR((char *str));
+LOCAL	void	alt_S_video	__PR((char *str));
+LOCAL	void	alt_B_video	__PR((char *str));
+LOCAL	void	alt_U_video	__PR((char *str));
 LOCAL	void	sscr		__PR((int b, int e));
 LOCAL	void	sup_S		__PR((int n));
 LOCAL	void	sup_M		__PR((int n));
@@ -259,7 +259,7 @@ LOCAL	void	setupttycmds	__PR((void));
  * outchar() is a pointer to the function that is used to send
  * the control sequences to the terminal.
  *
- * Returns: 
+ * Returns:
  *	NULL	- success
  *	!= NULL	- pointer to string with error message
  */
@@ -286,10 +286,10 @@ tty_start(outchar)
 /*		unknown++;*/
 /*		strcpy(tbuf, "xx|dumb:");*/
 		if (ret == -1) {
-			js_snprintf(_stbuf, sizeof(_stbuf),
+			js_snprintf(_stbuf, sizeof (_stbuf),
 					"Cannot open termcap file.\n");
 		} else {
-			js_snprintf(_stbuf, sizeof(_stbuf),
+			js_snprintf(_stbuf, sizeof (_stbuf),
 					"Cannot find terminal type: %s.\n",
 								tname);
 		}
@@ -297,7 +297,7 @@ tty_start(outchar)
 	}
 
 	if (errstr)		/* XXX */
-		return(errstr);
+		return (errstr);
 
 	if ((pagesize = tgetnum("li")) <= 1)
 		pagesize = 2;
@@ -378,7 +378,7 @@ EXPORT char *
 tty_fkey(n)
 	int	n;
 {
-	if (n >= 0 && n < (sizeof(tfkeys)/sizeof(tfkeys[0])))
+	if (n >= 0 && n < (sizeof (tfkeys)/sizeof (tfkeys[0])))
 		return (*tfkeys[n]);
 	return ((char *)0);
 }
@@ -746,7 +746,7 @@ gettc()
 	register char	*np;
 	register char	**fp;
 	register char	***sp;
-		 char	*sbp;
+		char	*sbp;
 
 	sbp = _stbuf;
 
@@ -782,12 +782,18 @@ gettc()
 
 	stbp = sbp;
 
-	if (XS)
+	if (XS) {
 		SO = SE = NULL;
-	else {
-		if (tgetnum("sg") > 0)
+	} else {
+		/*
+		 * Enter/Exit Standout Glitch present?
+		 */
+		if (tgetnum("sg") > 0)	/* # of glitch chars left by so or se*/
 			SO = NULL;
-		if (tgetnum("ug") > 0)
+		/*
+		 * Enter/Exit Underline Glitch present?
+		 */
+		if (tgetnum("ug") > 0)	/* # of glitch chars left by us or ue*/
 			US = NULL;
 		if (!SO && US) {
 			SO = US;
@@ -798,12 +804,12 @@ gettc()
 	/*
 	 * Handle funny termcap capabilities
 	 */
-	if (CS && SC && RC) AL=DL="";		/* XXX */
-	if (AL_PARM && AL==NULL) AL="";
-	if (DL_PARM && DL==NULL) DL="";
-	if (IC && IM==NULL) IM="";
-	if (IC && EI==NULL) EI="";
-	if (IM==NULL || EI==NULL) IM=EI=NULL;
+	if (CS && SC && RC) AL = DL = "";	/* XXX */
+	if (AL_PARM && AL == NULL) AL = "";
+	if (DL_PARM && DL == NULL) DL = "";
+	if (IC && IM == NULL) IM = "";
+	if (IC && EI == NULL) EI = "";
+	if (IM == NULL || EI == NULL) IM = EI = NULL;
 	if (!XT) GT = 0;	/* Do not use tabs if destructive */
 	if (!GT) BT = NULL;	/* If we can't tab, we can't backtab either */
 
@@ -838,12 +844,12 @@ setupttycmds()
 	kl = tgetstr("kl", &sbp);		/* Corsor left */
 	kB = tgetstr("kB", &sbp);		/* Corsor leftmost */
 	kE = tgetstr("kE", &sbp);		/* Corsor rightmost */
-	if (ku) _add_map (ku, "");		/* Corsor up */
-	if (kd) _add_map (kd, "");		/* Corsor down */
-	if (kr) _add_map (kr, "");		/* Corsor forward */
-	if (kl) _add_map (kl, "");		/* Corsor left */
-	if (kB) _add_map (kB, "");		/* Corsor leftmost */
-	if (kE)	_add_map (kE, "");		/* Corsor rightmost */
+	if (ku) _add_map(ku, "");		/* Corsor up */
+	if (kd) _add_map(kd, "");		/* Corsor down */
+	if (kr) _add_map(kr, "");		/* Corsor forward */
+	if (kl) _add_map(kl, "");		/* Corsor left */
+	if (kB) _add_map(kB, "");		/* Corsor leftmost */
+	if (kE)	_add_map(kE, "");		/* Corsor rightmost */
 #endif
 
 	if (CA)
