@@ -1,12 +1,12 @@
-/* @(#)ved.c	1.55 01/10/27 Copyright 1984 J. Schilling */
+/* @(#)ved.c	1.62 04/03/12 Copyright 1984, 85, 86, 88, 89, 97, 2000-2004 J. Schilling */
 #ifndef lint
 static	char sccsid[] =
-	"@(#)ved.c	1.55 01/10/27 Copyright 1984 J. Schilling";
+	"@(#)ved.c	1.62 04/03/12 Copyright 1984, 85, 86, 88, 89, 97, 2000-2004 J. Schilling";
 #endif
 /*
  *	VED Visual EDitor
  *
- *	Copyright (c) 1984 J. Schilling
+ *	Copyright (c) 1984, 85, 86, 88, 89, 97, 2000-2004 J. Schilling
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -19,9 +19,9 @@ static	char sccsid[] =
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; see the file COPYING.  If not, write to the Free Software
+ * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*
@@ -45,37 +45,38 @@ static	char sccsid[] =
 #include <signal.h>
 #include <sigblk.h>
 
-EXPORT	char	ved_version[] = "1.6";
-EXPORT	int	mflag;		/* if > 0 : take characters from macro	     */
-EXPORT	int	ReadOnly;	/* if > 0 : do not allow to write back mods  */
+EXPORT	char	ved_version[] = "1.7a03";
+EXPORT	int	mflag;		/* if > 0 : take characters from macro	    */
+EXPORT	int	ReadOnly;	/* if > 0 : do not allow to write back mods */
 
-EXPORT	int	nobak = 0;	/* Es wird kein ___.bak angelegt	     */
-EXPORT	int	dotags = 0;	/* "Filename" ist ctag			     */
-EXPORT	Llong	startline = -1;	/* Cursorposition Bei Start		     */
-EXPORT	int	noedtmp = 0;	/* Kein .vedtmp erzeugen		     */
-EXPORT	int	recover = 0;	/* altes File reparieren		     */
+EXPORT	int	nobak = 0;	/* Es wird kein ___.bak angelegt	    */
+EXPORT	int	nolock = 0;	/* Es wird kein record locking versucht	    */
+EXPORT	int	dotags = 0;	/* "Filename" ist ctag			    */
+EXPORT	Llong	startline = -1;	/* Cursorposition Bei Start		    */
+EXPORT	int	noedtmp = 0;	/* Kein .vedtmp erzeugen		    */
+EXPORT	int	recover = 0;	/* altes File reparieren		    */
 
-EXPORT	int	nfiles;		/* Anzahl der zu editierenden Files	     */
-EXPORT	int	fileidx = 0;	/* Index des editierten Files		     */
-EXPORT	Uchar	**files;	/* Array der zu editierenden Files	     */
-EXPORT	Uchar	curfname[FNAMESIZE]; /* global file name storage space	     */
+EXPORT	int	nfiles;		/* Anzahl der zu editierenden Files	    */
+EXPORT	int	fileidx = 0;	/* Index des editierten Files		    */
+EXPORT	Uchar	**files;	/* Array der zu editierenden Files	    */
+EXPORT	Uchar	curfname[FNAMESIZE]; /* global file name storage space	    */
 
 EXPORT	int	pid;		/* process id used for unique tmp file names */
 
 #ifndef	BFSIZE
-LOCAL	Uchar bufferout[BUFSIZ];/* To inhibit line buffering on stdout	     */
+LOCAL	Uchar bufferout[BUFSIZ]; /* To inhibit line buffering on stdout	    */
 #endif
 
 EXPORT	ewin_t	rootwin;
 
 LOCAL	void	usage		__PR((int exitcode));
-EXPORT	int	main		__PR((int ac, char** av));
+EXPORT	int	main		__PR((int ac, char **av));
 LOCAL	int	handlesignal	__PR((void));
 LOCAL	void	hupintr		__PR((int sig));
 LOCAL	void	exintr		__PR((int sig));
 EXPORT	void	settmodes	__PR((ewin_t *wp));
 EXPORT	void	rsttmodes	__PR((ewin_t *wp));
-LOCAL	Uchar*	gethelpfile	__PR((void));
+LOCAL	Uchar	*gethelpfile	__PR((void));
 
 LOCAL void
 usage(exitcode)
@@ -89,6 +90,7 @@ usage(exitcode)
 	error("	buffers=#	# of %d KB Incore Buffers (default is %d).\n",
 						BUFFERSIZE/1024, MAXBUFFERS);
 	error("	-nobak		Don't create filename.bak.\n");
+	error("	-nolock		Don't lock the edited file for writing.\n");
 	error("	-edtmp		Don't write to .vedtmp.\n");
 	error("	-raw8		Don't expand 8bit chars.\n");
 	error("	-dos		Map '\\n' to '\\r\\n', supress '\\r' in '\\r\\n'.\n");
@@ -107,7 +109,7 @@ usage(exitcode)
 }
 
 LOCAL	char	opts[] =
-"help,version,readonly+,r+,vhelp,v,buffers#,b#,nobak,n,raw8,dos,d,tag,t,wrapmargin#,w#,maxlinelen#,maxll#,+#LL,s*,edtmp,e,Recover,R";
+"help,version,readonly+,r+,vhelp,v,buffers#,b#,nobak,n,nolock,raw8,dos,d,tag,t,wrapmargin#,w#,maxlinelen#,maxll#,+#LL,s*,edtmp,e,Recover,R";
 
 EXPORT int
 main(ac, av)
@@ -123,6 +125,7 @@ main(ac, av)
 	int		buffers = -1;
 	Uchar		*errstr;
 	SIGBLK		sigblk;
+	SIGBLK		sigfirst;
 	int		err;
 	char		*searchstr = NULL;
 	ewin_t		*wp = &rootwin;
@@ -133,19 +136,20 @@ main(ac, av)
 	++cav, --cac;
 
 	if (getallargs(&cac, &cav, opts,
-			 &help, &prvers,
-			 &ReadOnly, &ReadOnly,
-			 &Vhelp, &Vhelp,
-			 &buffers, &buffers,
-			 &nobak, &nobak,
-			 &wp->raw8,
-			 &wp->dosmode, &wp->dosmode,
-			 &dotags, &dotags,
-			 &wp->wrapmargin, &wp->wrapmargin,
-			 &wp->maxlinelen, &wp->maxlinelen, 
-			 &startline, &searchstr,
-			 &noedtmp, &noedtmp,
-			 &recover, &recover) < 0) {
+			&help, &prvers,
+			&ReadOnly, &ReadOnly,
+			&Vhelp, &Vhelp,
+			&buffers, &buffers,
+			&nobak, &nobak,
+			&nolock,
+			&wp->raw8,
+			&wp->dosmode, &wp->dosmode,
+			&dotags, &dotags,
+			&wp->wrapmargin, &wp->wrapmargin,
+			&wp->maxlinelen, &wp->maxlinelen,
+			&startline, &searchstr,
+			&noedtmp, &noedtmp,
+			&recover, &recover) < 0) {
 		errmsgno(EX_BAD, "Bad flag '%s'.\n", cav[0]);
 		usage(EX_BAD);
 	}
@@ -153,7 +157,7 @@ main(ac, av)
 		usage(0);
 	if (prvers) {
 		printf("ved %s (%s-%s-%s)\n\n", ved_version, HOST_CPU, HOST_VENDOR, HOST_OS);
-		printf("Copyright (C) 1984, 85, 86, 88, 89, 97, 2000 Jrg Schilling\n");
+		printf("Copyright (C) 1984, 85, 86, 88, 89, 97, 2000-2004 Jrg Schilling\n");
 		printf("This is free software; see the source for copying conditions.  There is NO\n");
 		printf("warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
 		exit(0);
@@ -168,8 +172,15 @@ main(ac, av)
 		strcpy(C sbuf, searchstr);
 		sflg = strlen(C sbuf);
 	}
-	if (strstr(av[0], "-e")) {
-		noedtmp = 1;
+	/*
+	 * Look for being called as ved-e or ved-w
+	 */
+	if ((errstr = (Uchar *)strrchr(av[0], '-')) != NULL) {
+		errstr++;
+		if (strchr((char *)errstr, 'e'))
+			noedtmp = 1;
+		if (strchr((char *)errstr, 'w') && wp->maxlinelen == 0)
+			wp->maxlinelen = 79;
 	}
 	cav = av, cac = ac;
 	++cav, --cac;
@@ -179,6 +190,7 @@ main(ac, av)
 	get_modes(wp);			/* Get old ttymodes from tty driver  */
 	signal(SIGHUP, hupintr);
 	signal(SIGTERM, hupintr);
+	starthandlecond(&sigfirst);
 	handlecond("any_other", &sigblk, (handlefunc_t)handlesignal, 0L);
 
 	/*
@@ -193,15 +205,15 @@ main(ac, av)
 	wp->markwrap = TRUE;
 	wp->magic = TRUE;
 	wp->eflags = COLUPDATE|SAVEDEL;
-	wp->number = 1;			/* curnum is copied from this mult # master  */
-	wp->curnum = 1;			/* mult # fot next edit command		     */
-	wp->tabstop = 8;		/* Breite eines 'tabs'		     */
-	wp->optline = wp->psize/2;	/* set standard screen adjustment    */
-	wp->curfd = -1;			/* Kein File writelock vorhanden     */
-	set_modes();			/* set "ved" ttymodes		     */
-	t_begin();			/* init terminal state for editing   */
-	pid = getpid();			/* set pid for unique temp file names*/
-	initnum();			/* init number commands		     */
+	wp->number = 1;			/* curnum is copied from this mult # master */
+	wp->curnum = 1;			/* mult # fot next edit command	    */
+	wp->tabstop = 8;		/* Breite eines 'tabs'		    */
+	wp->optline = wp->psize/2;	/* set standard screen adjustment   */
+	wp->curfd = -1;			/* Kein File writelock vorhanden    */
+	set_modes();			/* set "ved" ttymodes		    */
+	t_begin();			/* init terminal state for editing  */
+	pid = getpid();			/* set pid for unique temp file names */
+	initnum();			/* init number commands		    */
 
 	if (Vhelp) {
 		/*
@@ -272,20 +284,20 @@ main(ac, av)
 	}
 
 	if (isatty(fdown(stdin)))	/* don't buffer stdin if it is a tty */
-		setbuf(stdin, NULL);	/* so we get no pre read !!!	     */
+		setbuf(stdin, NULL);	/* so we get no pre read !!!	    */
 #ifdef	BFSIZE
-	setbuf(stdout, NULL);		/* Buffering on stdout is done in _bb*/
+	setbuf(stdout, NULL);		/* Buffering on stdout is done in _bb */
 #else
-	setbuf(stdout, bufferout);	/* Inhibit line buffering on stdout  */
+	setbuf(stdout, bufferout);	/* Inhibit line buffering on stdout */
 #endif
 
-	init_charset(wp);		/* Initialisierung der char Laengen  */
-					/* und Strings			     */
+	init_charset(wp);		/* Initialisierung der char Laengen */
+					/* und Strings			    */
 
-	init_binding();			/* Initialisierung der Bindung von   */
-					/* Funktioinen an Zeichen	     */
+	init_binding();			/* Initialisierung der Bindung von  */
+					/* Funktioinen an Zeichen	    */
 
-	tmpsetup();			/* Init several tmp file names	     */
+	tmpsetup();			/* Init several tmp file names	    */
 
 	/*
 	 * Initialize the paged virtual memory and the status line.
@@ -311,8 +323,8 @@ main(ac, av)
 			/* NOTREACHED */
 
 		case  1:
-			strncpy(C curfname, C wp->curfile, sizeof(curfname));
-			curfname[sizeof(curfname)-1] = '\0';
+			strncpy(C curfname, C wp->curfile, sizeof (curfname));
+			curfname[sizeof (curfname)-1] = '\0';
 			wp->curfile = curfname;
 		}
 	}
@@ -346,10 +358,10 @@ main(ac, av)
 	CLEAR_SCREEN(wp);
 	refreshmsg(wp);
 
-	tmpopen(wp);			/* Open several temporary files	     */
+	tmpopen(wp);			/* Open several temporary files	    */
 
 	settakename(wp, UC "default");
-	(void)wrtcheck(wp, FALSE);
+	(void) wrtcheck(wp, FALSE);
 	writelockmsg(wp);
 	writenum(wp, wp->number);
 	macro_init(wp);
@@ -369,6 +381,7 @@ main(ac, av)
 	newprot(wp);
 	edit(wp);
 
+	unhandlecond(&sigfirst);
 	return (0);	/* Keep lint happy */
 }
 
@@ -379,7 +392,7 @@ LOCAL int
 handlesignal()
 {
 	rsttmodes(&rootwin);	/* XXX -> (ewin_t *)0 ??? */
-	return(0);
+	return (0);
 }
 
 /*
@@ -461,14 +474,14 @@ gethelpfile()
 	if (path == NULL)
 		return (hfile);
 
-	for(;;) {
+	for (;;) {
 		np = nbuf;
-		while (*path != ':' && *path != '\0'
-		    && np < &nbuf[sizeof(curfname)-sizeof(name)-1])
- 				*np++ = *path++;
+		while (*path != ':' && *path != '\0' &&
+		    np < &nbuf[sizeof (curfname)-sizeof (name)-1])
+				*np++ = *path++;
 		*np = '\0';
 		while (np > nbuf && np[-1] == '/')
-			*--np= '\0';
+			*--np = '\0';
 		if (np >= &nbuf[4] && streql(C &np[-4], "/bin"))
 			np = &np[-4];
 		*np++ = '/';
